from setuptools import setup
setup(
    name="whatanime",
    version="0.1",
    packages=["whatanime"],
    description="A Python library for interacting with whatanime.ga. I have no relationship with the owner of whatanime.ga.",
    url="https://github.com/lewbob9927/whatanime.py",
    author="Lewis Trowbridge",
    author_email="lewbob9927@gmail.com",
    install_requires=[
        "requests"
    ]
)
